@@ -16,5 +16,6 @@ class InputType(str, enum.Enum):
     DATA = "data"
 
 
-typic.register(deserializer=node_coercer, check=isnodetype)
+typic.register(deserializer=node_deserializer, check=isnodetype)
+typic.register(deserializer=log_deserializer, check=lambda o: o == LogueBodyT)
 typic.resolve()
