@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 import functools
-import ujson as json
+
+import typic
 
 from iambic import ast
 
@@ -10,10 +11,8 @@ class Parser:
     __resolver_map__ = ast.GenericNode.__resolver_map__
 
     @functools.lru_cache()
-    def parse(self, data: str) -> ast.ResolvedNode:
-        data = json.loads(data) if isinstance(data, str) else data
-        handler = self.__resolver_map__[data.pop("type")]
-        return handler(**data)
+    def parse(self, data: str) -> ast.ResolvedNodeT:
+        return typic.transmute(ast.ResolvedNodeT, data)
 
     __call__ = parse
 
